@@ -319,9 +319,14 @@ class OrderAPI(object):
         contents = self.get(url, key=key)
         return contents
 
-    def update_tag(self, number, identifier=None, type=None, activate=None):
+    def update_tag(self, number, identifier, type, **kwargs):
         url = self.base_url + "orders/%d/tag" % number
-        contents = self.put(url, identifier=identifier, type=type, activate=activate)
+        contents = self.put(url, identifier=identifier, type=type, **kwargs)
+        return contents
+
+    def delete_tag(self, number, **kwargs):
+        url = self.base_url + "orders/%d/tag" % number
+        contents = self.delete(url, **kwargs)
         return contents
 
     def activate_tag(self, number):
@@ -329,6 +334,11 @@ class OrderAPI(object):
         contents = self.put(url)
         return contents
 
+    def deactivate_tag(self, number):
+        url = self.base_url + "orders/%d/tag/deactivate" % number
+        contents = self.put(url)
+        return contents
+
     def import_order(
         self,
         ff_order_id,
